var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { loadCss, loadScript } from '@cnblogs/load-script-css';
import { defaultConfig, MathEngine, } from './model';
export class Mathjax2Renderer {
    constructor() {
        this._defaultConfig = defaultConfig[MathEngine.MathJax2];
        this._defaultMathJaxConfig = {
            tex2jax: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processClass: 'math',
                processEscapes: true,
            },
            TeX: {
                equationNumbers: {
                    autoNumber: 'AMS',
                    useLabelIds: true,
                },
                extensions: ['extpfeil.js', 'mediawiki-texvc.js'],
                Macros: { bm: '\\boldsymbol' },
            },
            CommonHTML: { linebreaks: { automatic: true } },
            'HTML-CSS': { linebreaks: { automatic: true } },
            SVG: { linebreaks: { automatic: true } },
            skipStartupTypeset: true,
        };
        this._config = this._defaultConfig;
    }
    get _global() {
        var _a;
        return ((_a = this._config.document.defaultView) !== null && _a !== void 0 ? _a : window);
    }
    render(container, callback) {
        if (!this._config.isEnabled)
            return Promise.resolve();
        return this.init()
            .then(mathjax => {
            if (!mathjax)
                return;
            const { onRendered } = this._config;
            mathjax.Hub.Queue(['Typeset', mathjax.Hub, container]);
            if (onRendered != null) {
                mathjax.Hub.Queue(() => onRendered(mathjax));
            }
            if (callback) {
                mathjax.Hub.Queue(callback);
            }
        })
            .catch(console.warn);
    }
    config(value) {
        this._config = Object.assign({}, this._defaultConfig, value);
        return this;
    }
    init() {
        if (this._initTask)
            return this._initTask;
        const { entryScript, tapMathJaxConfig, document } = this._config;
        return (this._initTask = loadScript({
            src: entryScript,
            id: 'mathjax',
            timeoutSeconds: 10,
            appendTo: document.head,
        })
            .then(() => {
            var _a;
            const { MathJax } = this._global;
            if (MathJax) {
                MathJax.Hub.Config((_a = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _a !== void 0 ? _a : Object.assign({}, this._defaultMathJaxConfig));
                MathJax.Hub.Configured();
                return MathJax;
            }
        })
            .catch(() => (this._initTask = undefined)));
    }
}
export class MathJax3Renderer {
    constructor() {
        this._defaultConfig = defaultConfig[MathEngine.MathJax3];
        this._defaultMathJaxConfig = {
            tex: {
                inlineMath: [
                    ['$', '$'],
                    ['\\(', '\\)'],
                ],
                processEscapes: true,
                tags: 'ams',
                useLabelIds: true,
                macros: {
                    bm: '\\boldsymbol',
                },
                packages: { '[+]': ['noerrors', 'extpfeil'] },
            },
            options: {
                processHtmlClass: 'math',
                ignoreHtmlClass: 'tex2jax_ignore',
            },
            loader: {
                load: ['[tex]/noerrors', '[tex]/extpfeil'],
            },
            startup: {
                typeset: false,
            },
        };
        this._config = this._defaultConfig;
    }
    config(value) {
        this._config = Object.assign({}, this._defaultConfig, value);
        return this;
    }
    render(container, callback) {
        if (!this._config.isEnabled)
            return Promise.resolve();
        return this.init()
            .then(mathjax => {
            mathjax
                ? (mathjax.startup.promise = mathjax.startup.promise.then(() => mathjax.typesetPromise([container]).then(() => {
                    var _a;
                    try {
                        (_a = this._config.onRendered) === null || _a === void 0 ? void 0 : _a.call(undefined, mathjax);
                    }
                    catch (e) {
                        console.error(e);
                    }
                    try {
                        callback === null || callback === void 0 ? void 0 : callback.call(undefined);
                    }
                    catch (e) {
                        console.error(e);
                    }
                })))
                : undefined;
        })
            .catch(console.warn);
    }
    init() {
        var _a;
        return ((_a = this._initTask) !== null && _a !== void 0 ? _a : (this._initTask = new Promise((resolve, reject) => {
            var _a, _b;
            const { entryScript, tapMathJaxConfig, document: _document } = this._config;
            const _window = ((_a = _document.defaultView) !== null && _a !== void 0 ? _a : window);
            _window.MathJax = (_b = tapMathJaxConfig === null || tapMathJaxConfig === void 0 ? void 0 : tapMathJaxConfig.call(undefined, Object.assign({}, this._defaultMathJaxConfig))) !== null && _b !== void 0 ? _b : Object.assign({}, this._defaultMathJaxConfig);
            if (!_window.MathJax.startup) {
                _window.MathJax.startup = {};
            }
            _window.MathJax.startup.ready = () => {
                var _a, _b;
                (_b = (_a = _window.MathJax) === null || _a === void 0 ? void 0 : _a.startup) === null || _b === void 0 ? void 0 : _b.defaultReady();
                resolve(_window.MathJax);
            };
            loadScript({
                src: entryScript,
                id: 'mathjax',
                executionStrategy: 'defer',
                appendTo: _window.document.head,
            }).catch(reject);
        }))).catch(() => (this._initTask = undefined));
    }
}
export class KatexRenderer {
    constructor() {
        this._defaultConfig = defaultConfig[MathEngine.Katex];
        this._defaultKatexOptions = {
            delimiters: [
                { left: "$$", right: "$$", display: true },
                { left: "$", right: "$", display: false },
                { left: "\\(", right: "\\)", display: false },
                { left: "\\[", right: "\\]", display: true }
            ],
        };
        this._config = this._defaultConfig;
        this._katexOption = Object.assign({}, this._defaultKatexOptions);
    }
    get _global() {
        var _a;
        return ((_a = this._config.document.defaultView) !== null && _a !== void 0 ? _a : window);
    }
    config(value) {
        this._config = Object.assign({}, this._defaultConfig, value);
        return this;
    }
    render(container, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this._config.isEnabled) {
                return Promise.resolve();
            }
            yield this.init();
            const global = this._global;
            global.renderMathInElement(container, this._katexOption);
            if (callback) {
                callback();
            }
        });
    }
    init() {
        var _a;
        return ((_a = this._initTask) !== null && _a !== void 0 ? _a : (this._initTask = new Promise((resolve, reject) => {
            const { entryScript, document: _document } = this._config;
            Promise.all([
                loadCss({
                    href: 'https://common.cnblogs.com/katex/0.16.8/katex.min.css',
                    id: 'katex-style',
                    appendTo: _document.head
                }),
                loadScript({
                    src: entryScript,
                    id: 'katex',
                    appendTo: _document.head,
                })
            ]).then(() => loadScript({
                src: 'https://common.cnblogs.com/katex/0.16.8/contrib/auto-render.min.js',
                id: 'katex-auto-render',
                appendTo: _document.head,
            }).then(() => {
                var _a, _b;
                this._katexOption = (_b = (_a = this._config.tapMathJaxConfig) === null || _a === void 0 ? void 0 : _a.call(undefined, this._katexOption)) !== null && _b !== void 0 ? _b : Object.assign({}, this._defaultKatexOptions);
                resolve();
            })).catch(reject);
        }))).catch(() => (this._initTask = undefined));
    }
}
//# sourceMappingURL=impl.js.map